@@ -1,4 +1,4 @@
 // use system colours
 pref("browser.display.use_system_colors", true);
-pref("browser.display.use_document_colors", false);
+//pref("browser.display.use_document_colors", false);
 
