@@ -2,7 +2,7 @@
 /*
  * Copyright (C) 2002 CodeFactory AB
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
- * Copyright (C) 2004-2005 Imendio AB
+ * Copyright (C) 2004-2006 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,6 +26,7 @@
 #include <string.h>
 #include <gtk/gtkmain.h>
 #include <gdk/gdkx.h>
+#include <gconf/gconf-client.h>
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
@@ -37,13 +38,14 @@
 #include "dh-preferences.h"
 #include "dh-base.h"
 
-#define d(x)
+#define d(x) 
 
 struct _DhBasePriv {
-	GSList     *windows;
-	GNode      *book_tree;
-	GList      *keywords;
-	GHashTable *books;
+	GSList      *windows;
+	GNode       *book_tree;
+	GList       *keywords;
+	GHashTable  *books;
+	GConfClient *gconf_client;
 };
 
 static void base_init                (DhBase      *base);
@@ -56,6 +58,7 @@ static void base_add_books           (DhBase      *base,
 
 
 static GObjectClass *parent_class;
+static DhBase       *base_instance;
 
 GType
 dh_base_get_type (void)
@@ -100,18 +103,42 @@ base_init (DhBase *base)
 	/* For some reason, libwnck doesn't seem to update its list of
 	 * workspaces etc if we don't do this.
 	 */
-	n_screens = gdk_display_get_n_screens (gdk_display_get_default());
+	n_screens = gdk_display_get_n_screens (gdk_display_get_default ());
 	for (i = 0; i < n_screens; i++) {
 		WnckScreen *screen;
 
 		screen = wnck_screen_get (i);
 	}
+
+	priv->gconf_client = gconf_client_get_default ();
+	gconf_client_add_dir (priv->gconf_client,
+			      GCONF_PATH,
+			      GCONF_CLIENT_PRELOAD_ONELEVEL,
+			      NULL);
+}
+
+static void
+dh_base_finalize (GObject *object)
+{
+        DhBasePriv *priv;
+
+	priv = DH_BASE (object)->priv;
+
+	g_object_unref (priv->gconf_client);
+	
+	dh_gecko_utils_shutdown ();
+
+	parent_class->finalize (object);
 }
 
 static void
 base_class_init (DhBaseClass *klass)
 {
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
 	parent_class = g_type_class_peek_parent (klass);
+
+	object_class->finalize = dh_base_finalize;
 }
 
 static void
@@ -195,42 +222,32 @@ base_sort_books (DhBase *base)
 }
 
 static void
-base_init_books (DhBase *base)
+base_add_books_in_data_dir (DhBase *base, const gchar *data_dir)
 {
-	const gchar *env;
-	gchar       *dir;
-
-	dir = g_build_filename (g_get_home_dir (), ".devhelp", "books", NULL);
+	gchar *dir;
+	
+	dir = g_build_filename (data_dir, "gtk-doc", "html", NULL);
 	base_add_books (base, dir);
 	g_free (dir);
 
-	env = g_getenv ("DEVHELP_SEARCH_PATH");
-	if (env) {
-		gchar **paths, **p;
+	dir = g_build_filename (data_dir, "devhelp", "books", NULL);
+	base_add_books (base, dir);
+	g_free (dir);
+}
 
-		paths = g_strsplit (env, ":", -1);
-		for (p = paths; *p != NULL; p++) {
-			base_add_books (base, *p);
-		}
-		g_strfreev (paths);
+static void
+base_init_books (DhBase *base)
+{
+	const gchar * const * system_dirs;
+
+	base_add_books_in_data_dir (base, g_get_user_data_dir ());
+
+	system_dirs = g_get_system_data_dirs ();
+	while (*system_dirs) {
+		base_add_books_in_data_dir (base, *system_dirs);
+		system_dirs++;
 	}
 
-	env = g_getenv ("GNOME2_PATH");
-	if (env) {
-		gchar **paths, **p;
-
-		paths = g_strsplit (env, ":", -1);
-		for (p = paths; *p != NULL; p++) {
-			base_add_books (base, *p);
-		}
-		g_strfreev (paths);
-	}
-
-	/* Insert the books from default gtk-doc install path. */
-	base_add_books (base, DATADIR "/gtk-doc/html");
-	base_add_books (base, "/usr/share/gtk-doc/html");
-	base_add_books (base, DATADIR "/devhelp/books");
-
 	base_sort_books (base);
 }
 
@@ -314,26 +331,29 @@ base_add_books (DhBase *base, const gchar *path)
 	g_dir_close (dir);
 }
 
+DhBase *
+dh_base_get (void)
+{
+	if (!base_instance) {
+		dh_gecko_utils_init ();
+		
+		base_instance = g_object_new (DH_TYPE_BASE, NULL);		
+
+		base_init_books (base_instance);
+		dh_preferences_init ();
+	}
+	
+	return base_instance;
+}
+
 DhBase *
 dh_base_new (void)
 {
-        DhBase          *base;
-	DhBasePriv      *priv;
-	static gboolean  initialized = FALSE;
-
-	if (!initialized) {
-		dh_gecko_utils_init_services ();
-		initialized = TRUE;
+	if (base_instance) {
+		g_error ("You can only have one DhBase instance.");
 	}
 
-        base = g_object_new (DH_TYPE_BASE, NULL);
-	priv = base->priv;
-
-	base_init_books (base);
-
-	dh_preferences_init ();
-
-	return base;
+	return dh_base_get ();
 }
 
 GtkWidget *
@@ -446,3 +466,14 @@ dh_base_get_window_on_current_workspace (DhBase *base)
 	return NULL;
 }
 
+GConfClient *
+dh_base_get_gconf_client (DhBase *base)
+{
+	DhBasePriv *priv;
+
+	g_return_val_if_fail (DH_IS_BASE (base), NULL);
+	
+	priv = base->priv;
+	
+	return priv->gconf_client;
+}
