@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2001-2003 CodeFactory AB
- * Copyright (C) 2001-2004 Imendio AB
+ * Copyright (C) 2001-2005 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,110 +20,113 @@
  */
 
 #include <config.h>
-#include <stdio.h>
 #include <string.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <dirent.h>
-#include <sys/socket.h>
-#include <sys/un.h>
-#include <libxml/parser.h>
-#include <gconf/gconf.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib/gi18n.h>
+#include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-program.h>
-#include <libgnomeui/gnome-ui-init.h>
-#include <libgnomevfs/gnome-vfs-init.h>
-#include <gtkmozembed.h>
 
 #include "bacon-message-connection.h"
 #include "dh-base.h"
-#include "dh-gecko-utils.h"
 #include "dh-window.h"
 
 #define COMMAND_QUIT   "quit"
 #define COMMAND_SEARCH "search"
 #define COMMAND_RAISE  "raise"
 
-gchar *geometry = NULL;
-
 static void
-message_received_cb (const gchar *message, DhWindow *window)
+message_received_cb (const gchar *message, DhBase *base)
 {
+	GtkWidget *window;
+	guint32    timestamp;
+		
 	if (strcmp (message, COMMAND_QUIT) == 0) {
 		gtk_main_quit ();
+		return;
 	}
-	else if (strncmp (message, COMMAND_SEARCH, strlen (COMMAND_SEARCH)) == 0) {
-		dh_window_search (window,
-				  message + strlen (COMMAND_SEARCH) + 1);
-	}
-	else if (strcmp (message, COMMAND_RAISE) == 0) {
+
+	/* Note: This is a bit strange. It seems like we need both the
+	 * gtk_window_present() and gtk_window_present_with_time() to make all
+	 * the cases working.
+	 */
+	
+	window = dh_base_get_window_on_current_workspace (base);
+	if (!window) {
+		window = dh_base_new_window (base);
 		gtk_window_present (GTK_WINDOW (window));
 	}
+	
+	if (strncmp (message, COMMAND_SEARCH, strlen (COMMAND_SEARCH)) == 0) {
+		
+		dh_window_search (DH_WINDOW (window),
+				  message + strlen (COMMAND_SEARCH) + 1);
+	}	
+	
+	timestamp = gdk_x11_get_server_time (window->window);
+	gtk_window_present_with_time (GTK_WINDOW (window), timestamp);
 }
 
-int 
+int
 main (int argc, char **argv)
 {
 	gchar                  *option_search = NULL;
 	gboolean                option_quit = FALSE;
-	GnomeProgram           *program;
+	gboolean                option_version = FALSE;
 	BaconMessageConnection *message_conn;
 	DhBase                 *base;
 	GtkWidget              *window;
-	
-	struct poptOption  options[] = {
+	GError                 *error = NULL;
+	GOptionEntry            options[] = {
 		{
-			"geometry",
-			'g',
-			POPT_ARG_STRING,
-			&geometry,
+			"search",
+			's',
 			0,
-			N_("Specify the size and location of the window"),
-			N_("WIDTHxHEIGHT+XOFF+YOFF")
+			G_OPTION_ARG_STRING,
+			&option_search,
+			_("Search for a function"),
+			NULL
 		},
-		{ 
-			"search",      
-			's',  
-			POPT_ARG_STRING, 
-			&option_search,    
-			0, 
-			_("Search for a function"),      
-			NULL 
+       		{
+			"quit",
+			'q',
+			0,
+			G_OPTION_ARG_NONE,
+			&option_quit,
+			_("Quit any running Devhelp"),
+			NULL
 		},
-		{ 
-			"quit",      
-			'q',  
-			POPT_ARG_NONE, 
-			&option_quit,    
-			0, 
-			_("Quit any running Devhelp"),      
-			NULL 
+       		{
+			"version",
+			'v',
+			0,
+			G_OPTION_ARG_NONE,
+			&option_version,
+			_("Display the version and exit"),
+			NULL
 		},
-		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
+		{
+			NULL, '\0', 0, 0, NULL, NULL, NULL
+		}
 	};
 	
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
 
-	g_thread_init (NULL);
+	if (!gtk_init_with_args (&argc, &argv, NULL, options, GETTEXT_PACKAGE, &error)) {
+		g_printerr ("%s\n", error->message);
+		return 1;
+	}
 
-	program = gnome_program_init (PACKAGE, VERSION,
-				      LIBGNOMEUI_MODULE,
-                                      argc, argv,
-                                      GNOME_PROGRAM_STANDARD_PROPERTIES,
-				      GNOME_PARAM_POPT_TABLE, options,
-                                      NULL);
-	LIBXML_TEST_VERSION;
+	if (option_version) {
+		g_print ("%s\n", PACKAGE_STRING);
+		return 0;
+	}
 
-	dh_gecko_utils_init_services ();
-	//gtk_moz_embed_set_comp_path (MOZILLA_HOME);
+	g_set_application_name (_("Devhelp"));
+	gtk_window_set_default_icon_name ("devhelp");
 
 	message_conn = bacon_message_connection_new ("Devhelp");
 	if (!bacon_message_connection_get_is_server (message_conn)) {
-
 		if (option_quit) {
 			bacon_message_connection_send (message_conn, COMMAND_QUIT);
 			return 0;
@@ -132,36 +135,44 @@ main (int argc, char **argv)
 		if (option_search) {
 			gchar *command;
 
-			command = g_strdup_printf ("%s %s", COMMAND_SEARCH,
+			command = g_strdup_printf ("%s %s",
+						   COMMAND_SEARCH,
 						   option_search);
+
 			bacon_message_connection_send (message_conn, command);
 			g_free (command);
+		} else {
+			bacon_message_connection_send (message_conn, COMMAND_RAISE);
 		}
 
 		gdk_notify_startup_complete ();
-		bacon_message_connection_send (message_conn, COMMAND_RAISE);
 		return 0;
 	}
-	
+
 	if (option_quit) {
 		/* No running Devhelps so just quit */
 		return 0;
 	}
-		
+
 	base = dh_base_new ();
 	window = dh_base_new_window (base);
 
-	bacon_message_connection_set_callback (message_conn,
-					       (BaconMessageReceivedFunc) message_received_cb,
-					       window);
+	bacon_message_connection_set_callback (
+		message_conn,
+		(BaconMessageReceivedFunc) message_received_cb,
+		base);
 
 	if (option_search) {
 		dh_window_search (DH_WINDOW (window), option_search);
 	}
-	
+
 	gtk_widget_show (window);
-		
+
 	gtk_main ();
 
+	g_object_unref (base);
+
+	bacon_message_connection_free (message_conn);
+
 	return 0;
 }
